using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Drawing;
using Syncfusion.Windows.Forms.Chart;

namespace DragDrop
{
	public partial class Form1 : Form
	{
		private bool isDragging = false;
		private ChartRegion currentRegion = null;
		private double xmin;
		private double ymax;
		private double ymin;
		private double xmax;
		private Point chartAreaPoint;
		private bool clicked = false;

		public Form1()
		{
			InitializeComponent();
			InitializeControlSettings();
		}

		private void InitializeControlSettings()
		{
			chartControl1.Font = new Font("Arial", 12F, FontStyle.Regular, GraphicsUnit.Point, ((0)));

			// Specify a ChartPalette:
			Color[] color = new Color[] { Color.FromArgb(185, 73, 141, 238), Color.FromArgb(185, 247, 179, 78), Color.FromArgb(185, 186, 66, 30) };
			chartControl1.Palette = ChartColorPalette.Custom;
			chartControl1.Model.ColorModel.CustomColors = color;
			chartControl1.Palette = ChartColorPalette.Custom;
			chartControl1.Text = "";

			chartControl1.ChartInterior = new BrushInfo(185, new BrushInfo(GradientStyle.Vertical, Color.LightBlue, Color.Azure));
			chartControl1.LegendPosition = ChartDock.Top;
			chartControl1.HidePartialLabels = true;

			chartControl1.PrimaryXAxis.ValueType = ChartValueType.DateTime;
			chartControl1.PrimaryXAxis.DateTimeFormat = "dd MMM yyyy";

			chartControl1.PrimaryYAxis.CustomOrigin = true;
			chartControl1.PrimaryYAxis.ValueType = ChartValueType.Double;
			chartControl1.PrimaryYAxis.DesiredIntervals = 6;
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			InitializeChartData();
		}

		protected void InitializeChartData()
		{
			ChartSeries series = chartControl1.Model.NewSeries("Drag and Drop Series", ChartSeriesType.Line);
			series.Text = series.Name;

			DateTime s = DateTime.Now;

			series.Points.Add(s.AddMonths(2), 15);
			series.Points.Add(s.AddMonths(3), 15);
			series.Points.Add(s.AddMonths(5), 15);
			series.Points.Add(s.AddMonths(7), 15);
			series.Points.Add(s.AddMonths(8), 15);
			series.Points.Add(s.AddMonths(11), 15);
			series.Points.Add(s.AddMonths(14), 15);
			series.Points.Add(s.AddMonths(16), 15);
			series.Points.Add(s.AddMonths(19), 15);
			series.Points.Add(s.AddMonths(29), 15);


			series.Style.Symbol.Shape = ChartSymbolShape.Circle;
			series.Style.Symbol.Size = new Size(5, 5);
			series.Style.Symbol.Color = Color.Red;


			chartControl1.Series.Add(series);

		}

		private double GetXValueForScreenPoint(Point areaPoint)
		{
			Point axisStartPoint = this.chartControl1.GetChartAreaCoordinates(xmin, ymin);
			Point axisEndPoint = this.chartControl1.GetChartAreaCoordinates(xmax, ymin);
			Point axisZeroPoint = this.chartControl1.GetChartAreaCoordinates(0, ymin);

			// Pixel lengths
			double fullLength = axisEndPoint.X - axisStartPoint.X;
			double length = axisEndPoint.X - axisZeroPoint.X;
			double axisOrigin = this.chartControl1.ChartArea.ClientRectangle.Width - fullLength - this.chartControl1.ChartAreaMargins.Right;
			double pointX = chartAreaPoint.X - axisOrigin - axisZeroPoint.X;

			double returnVal = pointX / length * xmax;
			return returnVal;
		}

		private double GetYValueForScreenPoint(Point areaPoint)
		{
			Point axisStartPoint = this.chartControl1.GetChartAreaCoordinates(xmin, ymin);
			Point axisEndPoint = this.chartControl1.GetChartAreaCoordinates(xmin, ymax);
			Point axisZeroPoint = this.chartControl1.GetChartAreaCoordinates(0, ymin);

			// Pixel lengths
			double length = axisEndPoint.Y - axisZeroPoint.Y;
			double pointY = chartAreaPoint.Y - axisZeroPoint.Y;

			double returnVal = pointY / length * ymax;
			return returnVal;
		}

		private Point ConvertScreenPointToChartAreaPoint(Point screenPoint)
		{
			Rectangle chartAreaRectangle = this.chartControl1.ChartArea.ClientRectangle;

			Point ccp = this.chartControl1.PointToClient(screenPoint);

			Point cap = new Point(ccp.X - chartAreaRectangle.X, ccp.Y - chartAreaRectangle.Y);

			return cap;
		}

		private void chartControl1_ChartRegionMouseHover(object sender, ChartRegionMouseEventArgs e)
		{
			if (e.Region.IsChartPoint)
			{
				Cursor = Cursors.Hand;
			}
			else
			{
				Cursor = Cursors.Default;
			}
		}

		private void chartControl1_ChartRegionClick(object sender, ChartRegionMouseEventArgs e)
		{
			clicked = !clicked;

			if (!clicked)
			{
				isDragging = !isDragging;
				clicked = false;
			}
		}

		private void chartControl1_ChartRegionMouseDown(object sender, ChartRegionMouseEventArgs e)
		{
			if (e.Region.IsChartPoint)
			{
				Cursor = Cursors.SizeAll;
				this.isDragging = !this.isDragging;
				this.currentRegion = e.Region;
			}
		}

		protected void GetAxisValues()
		{
			xmin = chartControl1.PrimaryXAxis.Range.Min;
			ymax = chartControl1.PrimaryYAxis.Range.Max;
			ymin = chartControl1.PrimaryYAxis.Range.Min;
			xmax = chartControl1.PrimaryXAxis.Range.Max;
		}

		private void chartControl1_ChartRegionMouseMove(object sender, ChartRegionMouseEventArgs e)
		{
			if (this.isDragging)
			{
				GetAxisValues();

				//Screen Coordinates to ChartArea coordinates
				chartAreaPoint = ConvertScreenPointToChartAreaPoint(Control.MousePosition);

				this.chartControl1.Series[0].Points[this.currentRegion.PointIndex].X = GetXValueForScreenPoint(chartAreaPoint);
				this.chartControl1.Series[0].Points[this.currentRegion.PointIndex].YValues[0] = GetYValueForScreenPoint(chartAreaPoint);
				double newX = Math.Round(GetXValueForScreenPoint(Control.MousePosition), 2);
				double newY = Math.Round(GetYValueForScreenPoint(Control.MousePosition), 2);
				toolTip1.SetToolTip(chartControl1, newX + ", " + newY);

				if (ymax <= newY)
				{
					//chartControl1.PrimaryYAxis.Origin = 0;
				}
				if (ymin >= newY)
				{
					//chartControl1.PrimaryYAxis.Origin = newY;
				}

				this.chartControl1.Refresh();
				this.chartControl1.Redraw(true);



			}
		}

	}
}

